summaryrefslogtreecommitdiff
path: root/features/user/gui/desktops/niri/parts
diff options
context:
space:
mode:
authortriethyl <triethylammonium@pm.me>2025-07-07 11:53:05 -0400
committertriethyl <triethylammonium@pm.me>2025-07-07 11:53:05 -0400
commitdc5ab02806c393460c6626fc633bc56f06d99189 (patch)
tree53f9f914fcf54da6bd4d835a46910018828b60fa /features/user/gui/desktops/niri/parts
parentc5ac02aa48b298648144b9dd41c984c504f1fc0d (diff)
removed foot server
Former-commit-id: 6299ea7698263684c2e33d759ddfebf0fd727b30
Diffstat (limited to 'features/user/gui/desktops/niri/parts')
-rw-r--r--features/user/gui/desktops/niri/parts/selectors.nix12
1 files changed, 6 insertions, 6 deletions
diff --git a/features/user/gui/desktops/niri/parts/selectors.nix b/features/user/gui/desktops/niri/parts/selectors.nix
index a70059e..6760191 100644
--- a/features/user/gui/desktops/niri/parts/selectors.nix
+++ b/features/user/gui/desktops/niri/parts/selectors.nix
@@ -22,20 +22,20 @@ in {
let tools = {
"rebuild nixos": {
# footclient -H sudo nixos-rebuild switch --flake ($"~/Sync/setup#(hostname)" | path expand)
- footclient -H nh os switch
+ foot -H nh os switch
}
"rebuild home": {
- # footclient -H home-manager switch --flake ($"~/Sync/setup#(whoami)@(hostname)" | path expand)
- footclient -H nh home switch
+ # foot -H home-manager switch --flake ($"~/Sync/setup#(whoami)@(hostname)" | path expand)
+ foot -H nh home switch
}
"update flake": {
- footclient -H nix flake update --flake ($"~/Sync/setup/" | path expand)
+ foot -H nix flake update --flake ($"~/Sync/setup/" | path expand)
}
"manage wifi": {
- footclient ${pkgs.impala}/bin/impala
+ foot ${pkgs.impala}/bin/impala
}
"manage bluetooth": {
- footclient ${lib.getExe pkgs.bluetui}
+ foot ${lib.getExe pkgs.bluetui}
}
"create qr-code": {
let temp_file = mktemp